@@ -1,7 +1,5 @@
 package Dist::Zilla::PluginBundle::SHLOMIF;
-$Dist::Zilla::PluginBundle::SHLOMIF::VERSION = '0.000006';
-our $AUTHORITY = 'cpan:SHLOMIF';
-
+$Dist::Zilla::PluginBundle::SHLOMIF::VERSION = '0.000007';
 use 5.014;
 
 use Moose;
@@ -301,7 +299,7 @@ Dist::Zilla::PluginBundle::SHLOMIF - Dist::Zilla plugins for me
 
 =head1 VERSION
 
-version 0.000006
+version 0.000007
 
 =head1 SYNOPSIS
 
@@ -374,6 +372,14 @@ equivalent to (FILL IN/update).
     [ContributorsFromGit]
     [MetaProvides::Package]
 
+=head1 NAME
+
+Dist::Zilla::PluginBundle::SHLOMIF - dzil plugins for SHLOMIF (Shlomi Fish)
+
+=head1 VERSION
+
+version 0.000007
+
 =head1 SEE ALSO
 
 L<Dist::Zilla>
